camelot.camelot.view.controls.schemer

Package camelot :: Package camelot :: Package view :: Package controls :: Module schemer |
[hide private]
[frames] | no frames]

# Module schemer

module that encapsulate various ms office schemes

Version: 0.1.0

Classes | [hide private]
| Schemer

Variables | [hide private]
| Office2003BlueStyle = ``{``'``BorderColor``'``:` `'``(21, 28, 171)``'``,` `'``Button``...``
| Office2003OliveStyle = ``{``'``BorderColor``'``:` `'``(134, 161, 105)``'``,` `'``But``...``
| Office2003SilverStyle = ``{``'``BorderColor``'``:` `'``(100, 97, 135)``'``,` `'``But``...``
| Office2007BlackStyle = ``{``'``BorderColor``'``:` `'``(76, 83, 92)``'``,` `'``Button``...``
| Office2007BlueStyle = ``{``'``BorderColor``'``:` `'``(101, 147, 207)``'``,` `'``Butt``...``
| Office2007SilverStyle = ``{``'``BorderColor``'``:` `'``(111, 112, 116)``'``,` `'``Bu``...``
| defaultUI = ``{``'``BorderColor``'``:` `'``(101, 147, 207)``'``,` `'``ButtonMouseOve``...``
| schemer = `<camelot.camelot.view.controls.schemer.Schemer insta`...``

Variables Details | [hide private]

  ### Office2003BlueStyle Value:
      {'BorderColor': '(21, 28, 171)',
       'ButtonMouseOverBegin': '(255, 253, 216)',
       'ButtonMouseOverEnd': '(248, 194, 95)',
       'ButtonMouseOverMiddleBegin': '(251, 222, 152)',
       'ButtonMouseOverMiddleEnd': '(251, 222, 152)',
       'ButtonNormalBegin': '(201, 223, 251)',
       'ButtonNormalEnd': '(129, 168, 226)',
       'ButtonNormalMiddleBegin': '(165, 196, 239)',
      ...

  ### Office2003OliveStyle Value:
      {'BorderColor': '(134, 161, 105)',
       'ButtonMouseOverBegin': '(255, 253, 216)',
       'ButtonMouseOverEnd': '(248, 194, 95)',
       'ButtonMouseOverMiddleBegin': '(251, 222, 152)',
       'ButtonMouseOverMiddleEnd': '(251, 222, 152)',
       'ButtonNormalBegin': '(233, 239, 205)',
       'ButtonNormalEnd': '(182, 196, 144)',
       'ButtonNormalMiddleBegin': '(208, 218, 176)',
      ...

  ### Office2003SilverStyle Value:
      {'BorderColor': '(100, 97, 135)',
       'ButtonMouseOverBegin': '(255, 253, 216)',
       'ButtonMouseOverEnd': '(248, 194, 95)',
       'ButtonMouseOverMiddleBegin': '(251, 222, 152)',
       'ButtonMouseOverMiddleEnd': '(251, 222, 152)',
       'ButtonNormalBegin': '(223, 224, 234)',
       'ButtonNormalEnd': '(150, 148, 178)',
       'ButtonNormalMiddleBegin': '(190, 190, 209)',
      ...

  ### Office2007BlackStyle Value:
      {'BorderColor': '(76, 83, 92)',
       'ButtonMouseOverBegin': '(255, 254, 228)',
       'ButtonMouseOverEnd': '(255, 230, 158)',
       'ButtonMouseOverMiddleBegin': '(255, 232, 167)',
       'ButtonMouseOverMiddleEnd': '(255, 215, 103)',
       'ButtonNormalBegin': '(248, 248, 249)',
       'ButtonNormalEnd': '(219, 222, 226)',
       'ButtonNormalMiddleBegin': '(223, 226, 228)',
      ...

  ### Office2007BlueStyle Value:
      {'BorderColor': '(101, 147, 207)',
       'ButtonMouseOverBegin': '(255, 254, 228)',
       'ButtonMouseOverEnd': '(255, 230, 158)',
       'ButtonMouseOverMiddleBegin': '(255, 232, 167)',
       'ButtonMouseOverMiddleEnd': '(255, 215, 103)',
       'ButtonNormalBegin': '(227, 239, 255)',
       'ButtonNormalEnd': '(192, 219, 255)',
       'ButtonNormalMiddleBegin': '(196, 221, 255)',
      ...

  ### Office2007SilverStyle Value:
      {'BorderColor': '(111, 112, 116)',
       'ButtonMouseOverBegin': '(255, 254, 228)',
       'ButtonMouseOverEnd': '(255, 230, 158)',
       'ButtonMouseOverMiddleBegin': '(255, 232, 167)',
       'ButtonMouseOverMiddleEnd': '(255, 215, 103)',
       'ButtonNormalBegin': '(235, 238, 250)',
       'ButtonNormalEnd': '(212, 216, 226)',
       'ButtonNormalMiddleBegin': '(214, 218, 228)',
      ...

  ### defaultUI Value:
      {'BorderColor': '(101, 147, 207)',
       'ButtonMouseOverBegin': '(255, 254, 228)',
       'ButtonMouseOverEnd': '(255, 230, 158)',
       'ButtonMouseOverMiddleBegin': '(255, 232, 167)',
       'ButtonMouseOverMiddleEnd': '(255, 215, 103)',
       'ButtonNormalBegin': '(227, 239, 255)',
       'ButtonNormalEnd': '(192, 219, 255)',
       'ButtonNormalMiddleBegin': '(196, 221, 255)',
      ...

  ### schemer Value:
      <camelot.camelot.view.controls.schemer.Schemer instance at 0x9bee5cc>